@@ -65,9 +65,12 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.containers.MongoDBContainer;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.junit.jupiter.Container;
 import org.testcontainers.junit.jupiter.Testcontainers;
 
@@ -84,19 +87,20 @@ import java.util.regex.Pattern;
 
 import static org.apache.flink.table.api.Expressions.row;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** IT tests for {@link MongoDynamicTableSink}. */
 @Testcontainers
-public class MongoDynamicTableSinkITCase {
+class MongoDynamicTableSinkITCase {
 
     private static final Logger LOG = LoggerFactory.getLogger(MongoDynamicTableSinkITCase.class);
 
     @Container
     private static final MongoDBContainer MONGO_CONTAINER =
-            MongoTestUtil.createMongoDBContainer(LOG);
+            MongoTestUtil.createMongoDBContainer().withLogConsumer(new Slf4jLogConsumer(LOG));
 
     @RegisterExtension
-    static final MiniClusterExtension MINI_CLUSTER_RESOURCE =
+    private static final MiniClusterExtension MINI_CLUSTER_RESOURCE =
             new MiniClusterExtension(
                     new MiniClusterResourceConfiguration.Builder()
                             .setNumberTaskManagers(1)
@@ -105,19 +109,19 @@ public class MongoDynamicTableSinkITCase {
     private MongoClient mongoClient;
 
     @BeforeEach
-    public void setUp() {
+    void setUp() {
         mongoClient = MongoClients.create(MONGO_CONTAINER.getConnectionString());
     }
 
     @AfterEach
-    public void tearDown() {
+    void tearDown() {
         if (mongoClient != null) {
             mongoClient.close();
         }
     }
 
     @Test
-    public void testSinkWithAllSupportedTypes() throws ExecutionException, InterruptedException {
+    void testSinkWithAllSupportedTypes() throws ExecutionException, InterruptedException {
         String database = "test";
         String collection = "sink_with_all_supported_types";
 
@@ -215,7 +219,7 @@ public class MongoDynamicTableSinkITCase {
     }
 
     @Test
-    public void testRoundTripReadAndSink() throws ExecutionException, InterruptedException {
+    void testRoundTripReadAndSink() throws ExecutionException, InterruptedException {
         String database = "test";
         String sourceCollection = "test_round_trip_source";
         String sinkCollection = "test_round_trip_sink";
@@ -297,7 +301,7 @@ public class MongoDynamicTableSinkITCase {
     }
 
     @Test
-    public void testSinkWithAllRowKind() throws ExecutionException, InterruptedException {
+    void testSinkWithAllRowKind() throws ExecutionException, InterruptedException {
         String database = "test";
         String collection = "test_sink_with_all_row_kind";
 
@@ -348,8 +352,9 @@ public class MongoDynamicTableSinkITCase {
         assertThat(actual).isEqualTo(expected);
     }
 
-    @Test
-    public void testSinkWithReservedId() throws Exception {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testSinkWithReservedId(boolean overwrite) throws Exception {
         String database = "test";
         String collection = "sink_with_reserved_id";
 
@@ -367,7 +372,7 @@ public class MongoDynamicTableSinkITCase {
 
         ObjectId objectId = new ObjectId();
         tEnv.fromValues(row(objectId.toHexString(), "r1"), row("str", "r2"))
-                .executeInsert("mongo_sink")
+                .executeInsert("mongo_sink", overwrite)
                 .await();
 
         MongoCollection<Document> coll =
@@ -385,7 +390,28 @@ public class MongoDynamicTableSinkITCase {
     }
 
     @Test
-    public void testSinkWithoutPrimaryKey() throws Exception {
+    void testOverwriteSinkWithoutPrimaryKey() {
+        String database = "test";
+        String collection = "overwrite_sink_without_primary_key";
+
+        TableEnvironment tEnv = TableEnvironment.create(EnvironmentSettings.inStreamingMode());
+
+        tEnv.executeSql(
+                String.format(
+                        "CREATE TABLE mongo_sink (" + "f1 STRING NOT NULL\n" + ")\n" + "WITH (%s)",
+                        getConnectorSql(database, collection)));
+
+        assertThatThrownBy(
+                        () ->
+                                tEnv.fromValues(row("d1"), row("d1"))
+                                        .executeInsert("mongo_sink", true)
+                                        .await())
+                .isInstanceOf(IllegalStateException.class)
+                .hasMessageContaining("Overwrite sink requires specifying the table's primary key");
+    }
+
+    @Test
+    void testSinkWithoutPrimaryKey() throws Exception {
         String database = "test";
         String collection = "sink_without_primary_key";
 
@@ -411,7 +437,7 @@ public class MongoDynamicTableSinkITCase {
     }
 
     @Test
-    public void testSinkWithNonCompositePrimaryKey() throws Exception {
+    void testSinkWithNonCompositePrimaryKey() throws Exception {
         String database = "test";
         String collection = "sink_with_non_composite_pk";
 
@@ -440,7 +466,7 @@ public class MongoDynamicTableSinkITCase {
     }
 
     @Test
-    public void testSinkWithCompositePrimaryKey() throws Exception {
+    void testSinkWithCompositePrimaryKey() throws Exception {
         String database = "test";
         String collection = "sink_with_composite_pk";
 
