@@ -65,6 +65,7 @@ import org.junit.jupiter.params.provider.EnumSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.containers.MongoDBContainer;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.junit.jupiter.Container;
 import org.testcontainers.junit.jupiter.Testcontainers;
 
@@ -81,6 +82,7 @@ import java.util.stream.Collectors;
 
 import static org.apache.flink.connector.mongodb.table.MongoConnectorOptions.COLLECTION;
 import static org.apache.flink.connector.mongodb.table.MongoConnectorOptions.DATABASE;
+import static org.apache.flink.connector.mongodb.table.MongoConnectorOptions.FILTER_HANDLING_POLICY;
 import static org.apache.flink.connector.mongodb.table.MongoConnectorOptions.URI;
 import static org.apache.flink.table.factories.FactoryUtil.CONNECTOR;
 import static org.assertj.core.api.Assertions.assertThat;
@@ -92,7 +94,7 @@ class MongoDynamicTableSourceITCase {
     private static final Logger LOG = LoggerFactory.getLogger(MongoDynamicTableSinkITCase.class);
 
     @RegisterExtension
-    static final MiniClusterExtension MINI_CLUSTER_RESOURCE =
+    private static final MiniClusterExtension MINI_CLUSTER_RESOURCE =
             new MiniClusterExtension(
                     new MiniClusterResourceConfiguration.Builder()
                             .setNumberTaskManagers(1)
@@ -100,7 +102,7 @@ class MongoDynamicTableSourceITCase {
 
     @Container
     private static final MongoDBContainer MONGO_CONTAINER =
-            MongoTestUtil.createMongoDBContainer(LOG);
+            MongoTestUtil.createMongoDBContainer().withLogConsumer(new Slf4jLogConsumer(LOG));
 
     private static final String TEST_DATABASE = "test";
     private static final String TEST_COLLECTION = "mongo_table_source";
@@ -241,9 +243,13 @@ class MongoDynamicTableSourceITCase {
         }
     }
 
-    @Test
-    void testFilter() {
-        tEnv.executeSql(createTestDDl(null));
+    @ParameterizedTest
+    @EnumSource(FilterHandlingPolicy.class)
+    void testFilter(FilterHandlingPolicy filterHandlingPolicy) {
+        tEnv.executeSql(
+                createTestDDl(
+                        Collections.singletonMap(
+                                FILTER_HANDLING_POLICY.key(), filterHandlingPolicy.name())));
 
         // we create a VIEW here to test column remapping, i.e. would filter push down work if we
         // create a view that depends on our source table
